# $File: //depot/OurNet-BBS/BBS/CVIC/Article.pm $ $Author: autrijus $
# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $

package OurNet::BBS::CVIC::Article;

use base qw/OurNet::BBS::MAPLE2::Article/;
use fields qw/_ego _hash/;

use OurNet::BBS::Base;

1;
